@@ -6,6 +6,8 @@
  * [-Wreturn-type]" by add a simple return line at the end of the
  * functions.
  *
+ * Macros relative to openmp are commented.
+ *
  * @section DESCRIPTION
  *
  * Calculate energy of sublimation from blowing snow.
@@ -392,7 +394,7 @@ trapzd(double (*funcd)(),
     // TODO: remove use of static variables (see GH #735), for now:
     // make static variables thread safe
     static double s;
-    #pragma omp threadprivate(s)
+    //#pragma omp threadprivate(s)
 
     if (n == 1) {
         return (s = 0.5 *
