@@ -1,5 +1,10 @@
 /******************************************************************************
-* @section DESCRIPTION
+ * @section MODIFICATION
+ *
+ * Modification by Ruida Zhong for the R package VICmodel on Sep 18th, 2018:
+ * Macro `ERROR` is rename by `VIC_ERROR` to avoid redefine.
+ *
+ * @section DESCRIPTION
 *
 * Calculates the interception and subsequent release of by the forest canopy
 * using an energy balance approach.
@@ -392,7 +397,7 @@ snow_intercept(double             Dt,
                                                     &RefreezeEnergy,
                                                     SensibleHeat,
                                                     VaporMassFlux);
-                return(ERROR);
+                return(VIC_ERROR);
             }
         }
 
@@ -828,5 +833,5 @@ error_print_canopy_energy_bal(double  Tfoliage,
              "Try increasing SNOW_DT to get model to complete cell.\n"
              "Then check output for instabilities.");
 
-    return(ERROR);
+    return(VIC_ERROR);
 }
